@@ -1,6 +1,6 @@
 /* io.c
  *
- * $Id: io.c,v 1.17 1999/08/31 20:57:35 bazsi Exp $ */
+ * $Id: io.c,v 1.18 1999/11/22 18:26:24 bazsi Exp $ */
 
 /* lsh, an implementation of the ssh protocol
  *
@@ -203,7 +203,7 @@ closes
 		{
 		case EAGAIN:
 		case EINTR:
-			return 1;
+			break;
 		default:
 			werror("io_iter: poll failed: %z", strerror(errno));
 			return 0;
@@ -217,8 +217,6 @@ closes
 		
 		for(fd = b->files, i=0; fd; fd = fd->next, i++)
 		{
-			assert(i<nfds);
-
 #if 0
 		        debug("io.c: poll for fd %i: events = 0x%xi, revents = 0x%xi.\n",
                 	      fds[i].fd, fds[i].events,fds[i].revents);
